@@ -498,6 +498,35 @@ StateNames = Literal["light", "motion", "audio", "doorbell", "siren", "battery",
 OnChangeCallback = Callable[[T, T], None]
 
 
+class AudioStreamOptions(TypedDict):
+    enabled: NotRequired[bool]
+    codec: NotRequired[str]
+    bitrate: NotRequired[int]
+    sampleRate: NotRequired[int]
+
+
+class VideoStreamOptions(TypedDict):
+    codec: NotRequired[str]
+    width: NotRequired[int]
+    height: NotRequired[int]
+    bitrate: NotRequired[int]
+    fps: NotRequired[int]
+    idrInterval: NotRequired[int]
+
+
+class StreamInfo(TypedDict):
+    audio: AudioStreamOptions
+    video: VideoStreamOptions
+
+
+class PrebufferState(TypedDict):
+    state: bool
+    url: NotRequired[Optional[str]]
+
+
+PrebufferContainer = Literal["mpegts", "mp4"]
+
+
 class CameraDelegate(ABC):
     @abstractmethod
     async def snapshot_request(self, request_id: str) -> bytes:
@@ -522,28 +551,33 @@ class CameraDelegate(ABC):
 
 class CameraPrebufferDelegate(ABC):
     @abstractmethod
-    async def is_prebuffering(self, source_name: str, type: str) -> bool:
-        pass
-
-    @abstractmethod
-    async def get_prebuffer_raw_url(self, source_name: str, type: str) -> Optional[str]:
-        pass
-
-    @abstractmethod
-    async def get_stream_info(self, source_name: str) -> Optional[dict[str, Any]]:
+    async def get_stream_info(self, source_name: str) -> Optional[StreamInfo]:
         pass
 
 
 class CameraSource(Protocol):
-    # CameraInput
-    id: str
+    # from CameraInput
+    id: str  # _id
     name: str
     roles: list["CameraRoles"]
     urls: StreamUrls
+    # end
 
-    async def is_prebuffering(self, type: str) -> bool: ...
-    async def get_prebuffer_raw_url(self, type: str) -> Optional[str]: ...
-    async def get_stream_info(self) -> Optional[dict[str, Any]]: ...
+    @overload
+    async def update_prebuffering_state(
+        self, container: PrebufferContainer, state: Literal[False]
+    ) -> None: ...
+    @overload
+    async def update_prebuffering_state(
+        self, container: PrebufferContainer, state: Literal[True], url: str
+    ) -> None: ...
+    async def update_prebuffering_state(
+        self, container: PrebufferContainer, state: bool, url: Optional[str] = None
+    ) -> None: ...
+
+    def get_prebuffering_state(self, container: PrebufferContainer) -> PrebufferState: ...
+    def on_prebuffering(self, container: PrebufferContainer) -> Observable[PrebufferState]: ...
+    async def get_stream_info(self) -> Optional[StreamInfo]: ...
 
 
 class ImageFormat(TypedDict):
@@ -619,7 +653,7 @@ class CameraDevice(Protocol):
     id: str
     plugin_id: str
     native_id: Optional[str] = None
-    state: bool
+    connected: bool
     disabled: bool
     name: str
     type: CameraType
